from typing import List


class OptionHolding(object):

    def __init__(self) -> None:
        pass

    def show(self) -> None:
        pass

    def _gen_ascii_tbl_data(self) -> List[List[str]]:
        pass
